# DeltaT — A simple time duration parser

Parse a time string e.g. '2h 13m' or '1.5d' into a timedelta object.

This is especially useful for command-line or configuration file parsing.

Based on Peter's answer at https://stackoverflow.com/a/51916936/2445204
and virhilo's answer at https://stackoverflow.com/a/4628148/851699

According to Peter, "any license is fine", Marcel concurs. For the sake of
specificity, stating MIT license here, which should be compatible with most
licenses.
